Enum WarningKind

pub enum WarningKind {
Show 41 variants Multichar, UnknownEscapeSequence, ImplicitlyUnsignedLiteral, LiteralRange, MissingDeclarations, DuplicateDeclSpecifier, ExternInitializer, Uninitialized, UnusedVariable, UnusedFunction, UnusedLocalTypedef, ExcessInitializers, MissingBraces, ManyBracesAroundScalarInit, LogicalOpParentheses, BitwiseOpParentheses, Parentheses, ArrayBounds, UnusedValue, UnusedComparison, DivisionByZero, IntegerOverflow, FloatingPointOverflow, ShiftCountNegative, ShiftCountOverflow, ShiftCountZero, ConstantConversion, ImplicitConversion, ImplicitPromotionConversion, ImplicitIntConversion, ImplicitFloatConversion, ImplicitIntFloatConversion, FloatConversion, SignConversion, PointerToIntCast, PointerBoolConversion, NonLiteralNullConversion, CompareDistinctPointerTypes, PointerIntegerCompare, ConditionalTypeMismatch, PointerTypeMismatch,
}
The kind of warning.

Variants



Multichar



UnknownEscapeSequence



ImplicitlyUnsignedLiteral



LiteralRange



MissingDeclarations



DuplicateDeclSpecifier



ExternInitializer



Uninitialized



UnusedVariable



UnusedFunction



UnusedLocalTypedef



ExcessInitializers



MissingBraces



ManyBracesAroundScalarInit



LogicalOpParentheses



BitwiseOpParentheses



Parentheses



ArrayBounds



UnusedValue



UnusedComparison



DivisionByZero



IntegerOverflow



FloatingPointOverflow



ShiftCountNegative



ShiftCountOverflow



ShiftCountZero



ConstantConversion



ImplicitConversion



ImplicitPromotionConversion



ImplicitIntConversion



ImplicitFloatConversion



ImplicitIntFloatConversion



FloatConversion



SignConversion



PointerToIntCast



PointerBoolConversion



NonLiteralNullConversion



CompareDistinctPointerTypes



PointerIntegerCompare



ConditionalTypeMismatch



PointerTypeMismatch

Implementations



impl WarningKind

pub const fn as_str(&self) -> &'static str

The string representation of the warning kind.

pub fn all() -> HashSet<WarningKind>

A HashSet of all the warnings.

pub fn all_strings() -> Vec<&'static str>

A sorted Vec of the string representations of all the warnings.



impl WarningKind

pub fn enabled_by_default() -> HashSet<WarningKind>

Returns a HashSet of compiler warnings that are enabled by default.