Struct Diagnostic

pub struct Diagnostic { /* private fields */ }
A diagnostic emitted by the compiler.

Implementations



impl Diagnostic

pub fn error(message: String) -> Self

Creates an error diagnostic with the given error message.

pub fn error_at_location(message: String, loc: SourceLocation) -> Self

Creates an error diagnostic with the given error message and source code location.

pub fn warning_at_location( kind: WarningKind, message: String, loc: SourceLocation, ) -> Self

Creates a new warning diagnostic with the given message and source code location.

pub fn convert_to_error(self) -> Self

Consumes the diagnostic and returns an equivalent with its kind set to DiagnosticKind:Error.

pub fn kind(&self) -> DiagnosticKind

The kind of diagnostic.

pub fn add_location(&mut self, loc: SourceLocation)

Adds an additional source location to the diagnostic.

pub fn add_note(&mut self, note: String, loc: Option<SourceLocation>)

Adds a note to the diagnostic.

pub fn add_note_with_suggested_code( &mut self, note: String, code: SuggestedCode, loc: Option<SourceLocation>, )

Adds a note to the diagnostic.