Enum SuggestedCode
pub enum SuggestedCode {
Code(String),
FormatString(String, Vec<SourceLocation>),
}Expand description
Suggested code.
Variants
Code(String)
Suggested code as a string.
FormatString(String, Vec<SourceLocation>)
A rudimentary and custom format string into which source code is inserted during diagnostic printing.
The original source code for each SourceLocation in the vector is inserted in the format string by
replacing $$<index> tokens, where index is 1-based.
E.g. “(char)($$1) = $$2”, vec![loc, another]